pub fn check_host_contract(
manifest: &AppManifest,
supported: &HostFeatureSet,
) -> Result<(), ManifestRejection>Expand description
Checks a parsed manifest against supported, and that any stamp is not stale.
pub fn check_host_contract(
manifest: &AppManifest,
supported: &HostFeatureSet,
) -> Result<(), ManifestRejection>Checks a parsed manifest against supported, and that any stamp is not stale.